/*
*  RAL -- Rubrica Addressbook Library
*  file: init.c
*
*  Copyright (C) 2006 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <glib.h>
#include <libintl.h>

#include "rlib.h"
#include "manager.h"
// #include "trash.h"
#include "group_set.h"
#include "timeout.h"

#define _(x) gettext(x)

RPluginManager *manager   = NULL;
RGroupSet      *group_set = NULL;
// RTrash         *trash     = NULL;
RTimeout       *timeout   = NULL;
GList          *adrbooks  = NULL;
     
gboolean init             = FALSE;
gchar*   release          = RUBRICA_VERSION;
gchar*   code_name        = LIBRAL_CODE_NAME;
gchar*   info_code_name   = LIBRAL_INFO_CODE_NAME;


static void r_lib_remove(gpointer obj, gpointer userdata);


static void 
r_lib_remove(gpointer obj, gpointer userdata)
{
  g_return_if_fail(obj != NULL);

  adrbooks = g_list_remove(adrbooks, obj);
}



gchar*
r_lib_get_release (void)
{
  return release;
}

gchar* 
r_lib_get_code_name(void)
{
  return code_name;
}

gchar*
r_lib_get_ral_info (void)
{
  return info_code_name;
}


gboolean 
r_lib_init(void)
{
  manager = r_plugin_manager_new();
  if(manager)
    r_plugin_manager_scan_directory(manager, LIBRAL_PLUGINS_DIR);      
  else
    g_error(_("\nCan't initialize r"));
  
  group_set = r_group_set_new();
  if (!group_set)
    g_error(_("\nCan't initialize r"));
/*
  trash = r_trash_new();
  if (!trash)
    g_error(_("\nCan't initialize r"));
*/ 
  timeout = r_timeout_new(0);
  if (!timeout)
    g_error(_("\nCan't initialize r"));

  init = TRUE;
  return init;
}


void
r_lib_admit(gpointer abook)
{
  g_signal_connect(G_OBJECT(abook), "addressbook_closed", 
		   G_CALLBACK(r_lib_remove), NULL);
  
  adrbooks = g_list_append(adrbooks, abook);
}



gboolean 
r_lib_is_running(void)
{
  return init;
}


gpointer 
r_lib_get_manager(void)
{
  return manager;
}


gpointer 
r_lib_get_group_set (void)
{
  return group_set;
}

/*
gpointer 
r_lib_get_trash (void)
{
  return trash;
}
*/

gpointer 
r_lib_get_timeout(void)
{
  return timeout;
}


GList* 
r_lib_get_addressbooks (void)
{
  return adrbooks;
}

